==> bubop-0.1.3a0.tar.gz: bubop-0.1.3a0/README.md <==
# bubop - Bergercookie's Useful Bits Of Python

<a href="https://github.com/bergercookie/bubop/actions" alt="CI">
<img src="https://github.com/bergercookie/bubop/actions/workflows/ci.yml/badge.svg" /></a>
<a href="https://github.com/pre-commit/pre-commit">
<img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white" alt="pre-commit"></a>

<img src="https://api.codacy.com/project/badge/Grade/9ddd71dc61914b32a0963d4101c29fb5"/></a>
<a href="https://www.codacy.com/app/bergercookie/bubop">
<img src="https://api.codacy.com/project/badge/Coverage/57206a822c41420bb5792b2cb70f06b5"/></a>
<a href="https://github.com/bergercookie/bubop/blob/master/LICENSE.md" alt="LICENSE">
<img src="https://img.shields.io/github/license/bergercookie/bubop.svg" /></a>
<a href="https://pypi.org/project/bubop/" alt="pypi">
<img src="https://img.shields.io/pypi/pyversions/bubop.svg" /></a>
<a href="https://badge.fury.io/py/bubop">
<img src="https://badge.fury.io/py/bubop.svg" alt="PyPI version" height="18"></a>
<a href="https://pepy.tech/project/bubop">
<img alt="Downloads" src="https://pepy.tech/badge/bubop"></a>
<a href="https://github.com/psf/black">
<img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>

## Description

This is a collection of python utils that I seem to be re-writing again and
again in all new python projects of mine.

## Installation

Just install them with pip:

```sh
pip3 install --user bubop

# Or via poetry:
poetry add bubop
```

## Extra configuration

## Example - Usage

==> bubop-0.1.8a0.tar.gz: bubop-0.1.8a0/README.md <==
# bubop - Bergercookie's Useful Bits Of Python

<a href="https://github.com/bergercookie/bubop/actions" alt="CI">
<img src="https://github.com/bergercookie/bubop/actions/workflows/ci.yml/badge.svg" /></a>
<a href="https://github.com/pre-commit/pre-commit">
<img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white" alt="pre-commit"></a>

<a href='https://coveralls.io/github/bergercookie/bubop?branch=master'>
<img src='https://coveralls.io/repos/github/bergercookie/bubop/badge.svg?branch=master' alt='Coverage Status' /></a>
<a href="https://github.com/bergercookie/bubop/blob/master/LICENSE.md" alt="LICENSE">
<img src="https://img.shields.io/github/license/bergercookie/bubop.svg" /></a>
<a href="https://pypi.org/project/bubop/" alt="pypi">
<img src="https://img.shields.io/pypi/pyversions/bubop.svg" /></a>
<a href="https://badge.fury.io/py/bubop">
<img src="https://badge.fury.io/py/bubop.svg" alt="PyPI version" height="18"></a>
<a href="https://pepy.tech/project/bubop">
<img alt="Downloads" src="https://pepy.tech/badge/bubop"></a>
<a href="https://github.com/psf/black">
<img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>

## Description

This is a collection of python utils that I seem to be re-writing again and
again in all new python projects of mine.

## Installation

Just install them with pip:

```sh
pip3 install --user bubop

# Or via poetry:
poetry add bubop
```

## Extra configuration

## Example - Usage
